@@ -4,62 +4,27 @@
  * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
-use super::{tokenizer::Token, Data, PartialDateTime};
-use crate::Parser;
-use mail_parser::{
-    decoders::{base64::base64_decode, hex::decode_hex},
-    DateTime,
+use super::{Data, PartialDateTime, tokenizer::Token};
+use crate::{
+    Parser,
+    common::{IanaParse, IanaString, IanaType},
+    icalendar::Uri,
 };
-use std::{borrow::Cow, iter::Peekable, slice::Iter, str::FromStr};
+use mail_parser::{
+    DateTime,
+    decoders::{base64::base64_decode, hex::decode_hex},
+};
+use std::{iter::Peekable, slice::Iter, str::FromStr};
 
 impl<'x> Parser<'x> {
-    pub(crate) fn buf_to_string(&mut self) -> String {
-        match self.token_buf.len() {
-            0 => String::new(),
-            1 => self.token_buf.pop().unwrap().into_string(),
-            _ => {
-                let from_offset = self.token_buf.first().unwrap().start;
-                let to_offset = self.token_buf.last().unwrap().end;
-
-                if self
-                    .token_buf
-                    .iter()
-                    .all(|t| matches!(t.text, Cow::Borrowed(_)))
-                {
-                    self.token_buf.clear();
-                    self.input
-                        .get(from_offset..=to_offset)
-                        .map(|slice| String::from_utf8_lossy(slice).into_owned())
-                        .unwrap_or_default()
-                } else {
-                    let mut string = String::with_capacity(to_offset - from_offset);
-                    for token in self.token_buf.drain(..) {
-                        string
-                            .push_str(std::str::from_utf8(token.text.as_ref()).unwrap_or_default());
-                    }
-                    string
-                }
-            }
-        }
-    }
-
-    pub(crate) fn buf_to_other<T: FromStr>(&mut self) -> Option<T> {
-        let result = self.token_buf.first().and_then(|token| {
-            std::str::from_utf8(token.text.as_ref())
-                .ok()
-                .and_then(|s| s.parse().ok())
-        });
-        self.token_buf.clear();
-        result
-    }
-
-    pub(crate) fn buf_to_bool(&mut self) -> bool {
-        let result = self
-            .token_buf
-            .pop()
-            .is_some_and(|token| token.text.as_ref().eq_ignore_ascii_case(b"TRUE"));
-        self.token_buf.clear();
-        result
+    pub(crate) fn raw_token(&mut self) -> Option<&'x str> {
+        self.token_buf
+            .first()
+            .and_then(|first| {
+                self.input
+                    .get(first.start..=self.token_buf.last().unwrap().end)
+            })
+            .and_then(|v| std::str::from_utf8(v).ok())
     }
 
     pub(crate) fn buf_parse_many<T: From<Token<'x>>>(&mut self) -> Vec<T> {
@@ -71,28 +36,73 @@ impl<'x> Parser<'x> {
         self.token_buf.clear();
         result
     }
-
-    pub(crate) fn buf_try_parse_one<T: for<'y> TryFrom<&'y [u8]>>(&mut self) -> Option<T> {
-        let result = self
-            .token_buf
-            .first()
-            .and_then(|t| T::try_from(t.text.as_ref()).ok());
-        self.token_buf.clear();
-        result
-    }
 }
 
 impl Token<'_> {
     pub(crate) fn into_uri_bytes(self) -> std::result::Result<Data, String> {
-        if self
-            .text
+        match Data::try_parse(self.text.as_ref()) {
+            Some(data) => Ok(data),
+            None => Err(self.into_string()),
+        }
+    }
+
+    pub(crate) fn into_timestamp(
+        self,
+        require_time: bool,
+    ) -> std::result::Result<PartialDateTime, String> {
+        let mut dt = PartialDateTime::default();
+        if dt.parse_timestamp(&mut self.text.iter().peekable(), require_time) {
+            Ok(dt)
+        } else {
+            Err(self.into_string())
+        }
+    }
+
+    pub(crate) fn into_offset(self) -> std::result::Result<PartialDateTime, String> {
+        let mut dt = PartialDateTime::default();
+        dt.parse_zone(&mut self.text.iter().peekable());
+        if !dt.is_null() {
+            Ok(dt)
+        } else {
+            Err(self.into_string())
+        }
+    }
+
+    pub(crate) fn into_float(self) -> std::result::Result<f64, String> {
+        if let Ok(text) = std::str::from_utf8(self.text.as_ref())
+            && let Ok(float) = text.parse::<f64>()
+        {
+            return Ok(float);
+        }
+
+        Err(self.into_string())
+    }
+
+    pub(crate) fn into_integer(self) -> std::result::Result<i64, String> {
+        if let Ok(text) = std::str::from_utf8(self.text.as_ref())
+            && let Ok(float) = text.parse::<i64>()
+        {
+            return Ok(float);
+        }
+
+        Err(self.into_string())
+    }
+
+    pub(crate) fn into_boolean(self) -> bool {
+        self.text.as_ref().eq_ignore_ascii_case(b"true")
+    }
+}
+
+impl Data {
+    pub fn try_parse(text: &[u8]) -> Option<Self> {
+        if text
             .as_ref()
             .get(0..5)
             .unwrap_or_default()
             .eq_ignore_ascii_case(b"data:")
         {
             let mut bin = Data::default();
-            let text = self.text.as_ref().get(5..).unwrap_or_default();
+            let text = text.as_ref().get(5..).unwrap_or_default();
             let mut offset_start = 0;
             let mut is_base64 = false;
 
@@ -131,65 +141,19 @@ impl Token<'_> {
                 if is_base64 {
                     if let Some(bytes) = base64_decode(text) {
                         bin.data = bytes;
-                        return Ok(bin);
+                        return Some(bin);
                     }
                 } else {
                     let (success, bytes) = decode_hex(text);
                     if success {
                         bin.data = bytes;
-                        return Ok(bin);
+                        return Some(bin);
                     }
                 }
             }
         }
 
-        Err(self.into_string())
-    }
-
-    pub(crate) fn into_timestamp(
-        self,
-        require_time: bool,
-    ) -> std::result::Result<PartialDateTime, String> {
-        let mut dt = PartialDateTime::default();
-        if dt.parse_timestamp(&mut self.text.iter().peekable(), require_time) {
-            Ok(dt)
-        } else {
-            Err(self.into_string())
-        }
-    }
-
-    pub(crate) fn into_offset(self) -> std::result::Result<PartialDateTime, String> {
-        let mut dt = PartialDateTime::default();
-        dt.parse_zone(&mut self.text.iter().peekable());
-        if !dt.is_null() {
-            Ok(dt)
-        } else {
-            Err(self.into_string())
-        }
-    }
-
-    pub(crate) fn into_float(self) -> std::result::Result<f64, String> {
-        if let Ok(text) = std::str::from_utf8(self.text.as_ref()) {
-            if let Ok(float) = text.parse::<f64>() {
-                return Ok(float);
-            }
-        }
-
-        Err(self.into_string())
-    }
-
-    pub(crate) fn into_integer(self) -> std::result::Result<i64, String> {
-        if let Ok(text) = std::str::from_utf8(self.text.as_ref()) {
-            if let Ok(float) = text.parse::<i64>() {
-                return Ok(float);
-            }
-        }
-
-        Err(self.into_string())
-    }
-
-    pub(crate) fn into_boolean(self) -> bool {
-        self.text.as_ref().eq_ignore_ascii_case(b"true")
+        None
     }
 }
 
@@ -303,19 +267,27 @@ impl PartialDateTime {
             && self.tz_minute.is_none()
     }
 
+    #[inline(always)]
     pub fn has_date(&self) -> bool {
         self.year.is_some() && self.month.is_some() && self.day.is_some()
     }
 
+    #[inline(always)]
     pub fn has_time(&self) -> bool {
         self.hour.is_some() && self.minute.is_some()
     }
 
+    #[inline(always)]
     pub fn has_zone(&self) -> bool {
         self.tz_hour.is_some()
     }
 
-    pub fn to_timestamp(&self) -> Option<i64> {
+    #[inline(always)]
+    pub fn has_date_and_time(&self) -> bool {
+        self.has_date() && self.has_time()
+    }
+
+    fn to_datetime(&self) -> Option<DateTime> {
         if self.has_date() && self.has_time() {
             DateTime {
                 year: self.year.unwrap(),
@@ -328,12 +300,19 @@ impl PartialDateTime {
                 tz_hour: self.tz_hour.unwrap_or_default(),
                 tz_minute: self.tz_minute.unwrap_or_default(),
             }
-            .to_timestamp()
             .into()
         } else {
             None
         }
     }
+
+    pub fn to_rfc3339(&self) -> Option<String> {
+        self.to_datetime().map(|dt| dt.to_rfc3339())
+    }
+
+    pub fn to_timestamp(&self) -> Option<i64> {
+        self.to_datetime().map(|dt| dt.to_timestamp())
+    }
 }
 
 pub(crate) fn parse_digits(
@@ -437,22 +416,18 @@ impl FromStr for Timestamp {
     }
 }
 
-impl TryFrom<&[u8]> for Timestamp {
-    type Error = ();
-
-    fn try_from(value: &[u8]) -> std::result::Result<Self, Self::Error> {
+impl IanaParse for Timestamp {
+    fn parse(value: &[u8]) -> Option<Self> {
         let mut dt = PartialDateTime::default();
         dt.parse_timestamp(&mut value.iter().peekable(), true);
-        dt.to_timestamp().map(Timestamp).ok_or(())
+        dt.to_timestamp().map(Timestamp)
     }
 }
 
 pub(crate) struct Integer(pub i64);
 
-impl TryFrom<&[u8]> for Integer {
-    type Error = ();
-
-    fn try_from(value: &[u8]) -> std::result::Result<Self, Self::Error> {
+impl IanaParse for Integer {
+    fn parse(value: &[u8]) -> Option<Self> {
         let mut num: i64 = 0;
         let mut is_negative = false;
 
@@ -467,13 +442,64 @@ impl TryFrom<&[u8]> for Integer {
                 }
                 _ => {
                     if !ch.is_ascii_whitespace() {
-                        return Err(());
+                        return None;
                     }
                 }
             }
         }
 
-        Ok(Integer(if is_negative { -num } else { num }))
+        Some(Integer(if is_negative { -num } else { num }))
+    }
+}
+
+pub(crate) struct Boolean(pub bool);
+
+impl IanaParse for Boolean {
+    fn parse(value: &[u8]) -> Option<Self> {
+        if value.eq_ignore_ascii_case(b"true") {
+            Some(Boolean(true))
+        } else if value.eq_ignore_ascii_case(b"false") {
+            Some(Boolean(false))
+        } else {
+            None
+        }
+    }
+}
+
+impl<I> From<Token<'_>> for IanaType<I, String>
+where
+    I: IanaParse,
+{
+    fn from(value: Token<'_>) -> Self {
+        I::parse(value.text.as_ref())
+            .map(IanaType::Iana)
+            .unwrap_or_else(|| IanaType::Other(value.into_string()))
+    }
+}
+
+impl<I> From<Token<'_>> for IanaType<I, Uri>
+where
+    I: IanaString
+        + IanaParse
+        + std::fmt::Debug
+        + Clone
+        + PartialEq
+        + Eq
+        + PartialOrd
+        + Ord
+        + std::hash::Hash,
+{
+    fn from(value: Token<'_>) -> Self {
+        I::parse(value.text.as_ref())
+            .map(IanaType::Iana)
+            .unwrap_or_else(|| {
+                IanaType::Other(
+                    value
+                        .into_uri_bytes()
+                        .map(Uri::Data)
+                        .unwrap_or_else(Uri::Location),
+                )
+            })
     }
 }
 
